# Changelog

## 0.1.0 (2022-09-19)

- Initial release on PyPI

## 0.1.1 (2022-09-19)

- Fix broken install due to wrong usage of setup.py
- Rename command line from alert_exporter to alert-exporter

## 0.2.0 (2022-09-20)

- Fix custom template handling when using packaged module
- Update docs
- Release beta version

## 0.2.1 (2022-09-20)

- Fix broken install resulting in ModuleNotFoundError
